==> priceloop-api-0.199.2.tar.gz: priceloop-api-0.199.2/priceloop_api/api/automation_api/set_workspace_automations.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.workspace_automations import WorkspaceAutomations
from ...types import Response


def _get_kwargs(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: WorkspaceAutomations,
) -> Dict[str, Any]:
    url = "{}/api/v1.0/workspaces/{workspace}/automations".format(client.base_url, workspace=workspace)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Any]:
    if response.status_code == HTTPStatus.OK:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: WorkspaceAutomations,
) -> Response[Any]:
    """Setup automations inside of a workspace

     For schedules, the cron-expression must follow the format defined here:
    https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-cron-expressions.html

    Args:
        workspace (str):  Example: workspace-name.
        json_body (WorkspaceAutomations):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: WorkspaceAutomations,
) -> Response[Any]:
    """Setup automations inside of a workspace

     For schedules, the cron-expression must follow the format defined here:
    https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-cron-expressions.html

    Args:
        workspace (str):  Example: workspace-name.
        json_body (WorkspaceAutomations):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)

==> priceloop-api-0.212.1.tar.gz: priceloop-api-0.212.1/priceloop_api/api/automation_api/set_workspace_automations.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.api_workspace_automations import ApiWorkspaceAutomations
from ...types import Response


def _get_kwargs(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: ApiWorkspaceAutomations,
) -> Dict[str, Any]:
    url = "{}/api/v1.0/workspaces/{workspace}/automations".format(client.base_url, workspace=workspace)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Any]:
    if response.status_code == HTTPStatus.OK:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: ApiWorkspaceAutomations,
) -> Response[Any]:
    """Setup automations inside of a workspace

     For schedules, the cron-expression must follow the format defined here:
    https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-cron-expressions.html

    Args:
        workspace (str):  Example: workspace-name.
        json_body (ApiWorkspaceAutomations):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    workspace: str,
    *,
    client: AuthenticatedClient,
    json_body: ApiWorkspaceAutomations,
) -> Response[Any]:
    """Setup automations inside of a workspace

     For schedules, the cron-expression must follow the format defined here:
    https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-cron-expressions.html

    Args:
        workspace (str):  Example: workspace-name.
        json_body (ApiWorkspaceAutomations):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)
